/*
 * Copyright (c) 2013-2023 NIBIO.
 *
 * This file is part of VIPSWeb 
 * (see https://gitlab.nibio.no/VIPS/VIPSWeb).
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */

// Couple of global elements
var map;
var observationLayer;

var initMap = function(geoJSON, poi, container, mapAttribution)
{
	var backgroundLayer = new ol.layer.Tile({
   	 	source: new ol.source.OSM({
   	 					attributions: [
                           new ol.Attribution({
                             html: mapAttribution
                           })
                         ]
                   })
    });
	
	// Creating the map
	map = new ol.Map({
			target: container,
			layers: [backgroundLayer],
			renderer: 'canvas'
	});
	
	// Setting zoom and center for the map (need to do this after creating map. so that we can transform our
	// center to correct map projection)
	var view = new ol.View({
		center: ol.proj.transform([10,65], 'EPSG:4326', map.getView().getProjection().getCode()),
		zoom: 7,
		maxZoom: 7
	});
	map.setView(view);
	
	var features = new ol.Collection();
	
	
	
	if(geoJSON != null)
	{
		var featureOverlay = new ol.layer.Vector({
		    source: new ol.source.Vector({
		      features: features
		    }),
		    style: new ol.style.Style({
		      fill: new ol.style.Fill({
		        color: 'rgba(255, 0, 255, 0.2)'
		      }),
		      stroke: new ol.style.Stroke({
		        color: '#ff00ff',
		        width: 2
		      }),
		      image: new ol.style.Circle({
		        radius: 7,
		        fill: new ol.style.Fill({
		          color: '#ff00ff'
		        })
		      })
		    })
		  });
	
	
		var format = new ol.format.GeoJSON();
		//console.log(JSON.parse(geoJSON));
	    var drawnfeatures = format.readFeatures(JSON.parse(geoJSON), {
	      dataProjection: 'EPSG:4326',
	      featureProjection: map.getView().getProjection().getCode()
	    });
	    //console.log(drawnfeatures);
    
	    // TODO: Convert small areas to points on large scale views
	    /**
	    for(var i in drawnfeatures)
	    {
	    	console.log(drawnfeatures[i].getGeometryName());
	    	var geome = drawnfeatures[i];
	    	if(geome.getGeometry() instanceof ol.geom.Polygon)
	    	{
	    		console.log(geome.getGeometry().getArea());
	    	}
	    	
	    }
	    console.log(drawnfeatures);
	    */
	    //featureOverlay.clear(true);
	    featureOverlay.getSource().addFeatures(drawnfeatures);
	    featureOverlay.setMap(map);
		
	    extent = featureOverlay.getSource().getExtent();
	    map.getView().fit(extent, map.getSize());
	}
	else if(poi != null)
	{
		/*var poiLayer = new ol.layer.Vector({
		    source: new ol.source.Vector({
		        url: settings.vipslogicProtocol + "://" + settings.vipslogicServerName + "/rest/pois/kml/" + settings.vipsOrganizationId + "?excludePoiId=" + poi.pointOfInterestId,
		            projection: "EPSG:3857",
		            format: new ol.format.KML()
		      })
		    });
		    map.addLayer(poiLayer);*/
		    var centerPosition =ol.proj.transform([poi.longitude,poi.latitude], 'EPSG:4326', map.getView().getProjection().getCode()); 
		    view.setCenter(centerPosition);
		    
		    // Marker overlay
		    stationMarker = new ol.Overlay({
		      position: centerPosition,
		      positioning: 'bottom-center',
		      element: document.getElementById('poiMarker'),
		      stopEvent: false
		    });
		    
		    map.addOverlay(stationMarker);
	}
}