/*
 * Copyright (c) 2013-2023 NIBIO.
 *
 * This file is part of VIPSWeb 
 * (see https://gitlab.nibio.no/VIPS/VIPSWeb).
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */

/**
 * Utility JavaScript. Used here and there. To whom it may concern... 
 *
 * @author Tor-Einar Skog <tor-einar.skog@nibio.no>
 */

function getOrganismLocalNameWithFallback(organism, currentLanguage, defaultLanguage)
{
	// Priority: Local name in current language, local name in default language, trade name, latin name
	var localeSet = organism["organismLocaleSet"];
	// Current language or default language
	var langs = [currentLanguage,defaultLanguage]
	for(var li in langs)
	{
		for(var i in localeSet)
		{
			if(localeSet[i]["organismLocalePK"]["locale"] == langs[li])
			{
				return localeSet[i]["localName"];
			}
		}
	}
	if(organism["tradeName"] != null && organism["tradeName"] != "")
	{
		return organism["tradeName"];
	}
	return organism["latinName"];
}

var compareOrganisms = function(a,b)
{
	var aName = getOrganismLocalNameWithFallback(a,settings.currentLanguage,settings.defaultLanguage);
	var bName = getOrganismLocalNameWithFallback(b,settings.currentLanguage,settings.defaultLanguage);
	return compareStrings(aName,bName);
}
